import React, { useState, useRef, useEffect, useMemo } from "react";
import {
    CreateBase,
    useTranslate,
    TextInput,
    NumberInput,
    BooleanInput,
    DateInput,
    SaveButton,
    SelectInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    Toolbar,
    required,
    PasswordInput,
    useNotify,
    Form,
    useCreateController,
    email,
} from 'react-admin';
import {
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Stack,
    Grid,
    Box,
} from '@mui/material';
import DialogCloseButton from "@/page/components/DialogCloseButton";
import StatusSelectInput from "@/page/components/StatusSelectInput";
import MemoInput from "@/page/components/MemoInput";
import TreeSelectInput from "@/page/components/TreeSelectInput";
import RolesSelect from './RolesSelect'

const UserCreate = (props) => {
    const { open, setOpen } = props;

    const translate = useTranslate();
    const notify = useNotify();

    const handleClose = (event, reason) => {
        if (reason !== "backdropClick") {
            setOpen(false);
        }
    };

    const handleSuccess = async (data) => {
        setOpen(false);
        notify('common.response.success');
    };

    const handleError = async (error) => {
        notify(error.message || 'common.response.fail', { type: 'error', messageArgs: { _: error.message } });
    };

    return (
        <>
            <CreateBase
                record={{}}
                transform={(data) => {
                    return data;
                }}
                mutationOptions={{ onSuccess: handleSuccess, onError: handleError }}
            >
                <Dialog
                    open={open}
                    onClose={handleClose}
                    aria-labelledby="form-dialog-title"
                    fullWidth
                    disableRestoreFocus
                    maxWidth="md"   // 'xs' | 'sm' | 'md' | 'lg' | 'xl'
                >
                    <Form validate={values => {
                        const errors = {};
                        if (!values.username) {
                            errors.username = 'ra.validation.required';
                        }
                        if (!values.nickname) {
                            errors.nickname = 'ra.validation.required';
                        }
                        if (!values.roleIds) {
                            errors.roleIds = 'ra.validation.required';
                        }
                        if (!values.email) {
                        } else {
                            const error = email()(values.email);
                            if (error) {
                                errors.email = error;
                            }
                        }
                        if (values.password && values.password !== values.confirmPassword) {
                            errors.confirmPassword = 'validate.pwdMisMatch';
                        }
                        return errors;
                    }}>
                        <DialogTitle id="form-dialog-title" sx={{
                            position: 'sticky',
                            top: 0,
                            backgroundColor: 'background.paper',
                            zIndex: 1000
                        }}
                        >
                            {translate('create.title')}
                            <Box sx={{ position: 'absolute', top: 8, right: 8, zIndex: 1001 }}>
                                <DialogCloseButton onClose={handleClose} />
                            </Box>
                        </DialogTitle>
                        <DialogContent sx={{ mt: 2 }}>
                            <Grid container rowSpacing={2} columnSpacing={2}>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.user.username"
                                        source="username"
                                        parse={v => v}
                                        autoFocus
                                        validate={required()}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.user.nickname"
                                        source="nickname"
                                        parse={v => v}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TreeSelectInput
                                        resource="dept"
                                        label="table.field.user.deptId"
                                        source="deptId"
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <RolesSelect
                                        label="table.field.user.role"
                                        source="roleIds"
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <PasswordInput
                                        label="table.field.user.password"
                                        source="password"
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <PasswordInput
                                        label="table.field.user.confirmPwd"
                                        source="confirmPassword"
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <SelectInput
                                        label="table.field.user.sex"
                                        source="sex"
                                        choices={[
                                            { id: 0, name: 'table.field.user.sexes.unknown' },
                                            { id: 1, name: 'table.field.user.sexes.male' },
                                            { id: 2, name: 'table.field.user.sexes.female' },
                                        ]}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.user.code"
                                        source="code"
                                        parse={v => v}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.user.phone"
                                        source="phone"
                                        parse={v => v}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.user.email"
                                        source="email"
                                        parse={v => v}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.user.realName"
                                        source="realName"
                                        parse={v => v}
                                    />
                                </Grid>
                                <Grid item xs={6} display="flex" gap={1}>
                                    <TextInput
                                        label="table.field.user.idCard"
                                        source="idCard"
                                        parse={v => v}
                                    />
                                </Grid>
                                <Grid item xs={12} display="flex" gap={1}>
                                    <Stack direction="column" spacing={1} width={'100%'}>
                                        <MemoInput />
                                    </Stack>
                                </Grid>
                            </Grid>
                        </DialogContent>
                        <DialogActions sx={{ position: 'sticky', bottom: 0, backgroundColor: 'background.paper', zIndex: 1000 }}>
                            <Toolbar sx={{ width: '100%', justifyContent: 'space-between' }}  >
                                <SaveButton />
                            </Toolbar>
                        </DialogActions>
                    </Form>
                </Dialog>
            </CreateBase>
        </>
    )
}

export default UserCreate;
